@@ -11,8 +11,8 @@
     You may need to install tables: 'pip install tables' or 'conda install pytables'
         
     Usage: 
-    python -m DLC_to_OpenPose -i "<input_h5_file>" -o "<output_json_folder>"
-    OR python -m DLC_to_OpenPose -i "<input_h5_file>"
+    python -m DLC_to_OpenPose -i input_h5_file -o output_json_folder
+    OR python -m DLC_to_OpenPose -i input_h5_file
     OR from Pose2Sim.Utilities import DLC_to_OpenPose; DLC_to_OpenPose.DLC_to_OpenPose_func(r'input_h5_file', r'output_json_folder')
 '''
 
@@ -31,7 +31,7 @@ __author__ = "David Pagnon"
 __copyright__ = "Copyright 2021, Pose2Sim"
 __credits__ = ["David Pagnon"]
 __license__ = "BSD 3-Clause License"
-__version__ = "0.1"
+__version__ = '0.4'
 __maintainer__ = "David Pagnon"
 __email__ = "contact@david-pagnon.com"
 __status__ = "Development"
@@ -43,8 +43,8 @@ def DLC_to_OpenPose_func(*args):
     Translates DeepLabCut (h5) 2D pose estimation files into OpenPose (json) files.
 
     Usage: 
-    DLC_to_OpenPose -i "<input_h5_file>" -o "<output_json_folder>"
-    OR DLC_to_OpenPose -i "<input_h5_file>"
+    DLC_to_OpenPose -i input_h5_file -o output_json_folder
+    OR DLC_to_OpenPose -i input_h5_file
     OR import DLC_to_OpenPose; DLC_to_OpenPose.DLC_to_OpenPose_func(r'input_h5_file', r'output_json_folder')
     '''
 
@@ -64,7 +64,7 @@ def DLC_to_OpenPose_func(*args):
     if not os.path.exists(json_folder_path):    
         os.mkdir(json_folder_path)
 
-  # json preparation
+    # json preparation
     json_dict = {'version':1.3, 'people':[]}
     json_dict['people'] = [{'person_id':[-1], 
                     'pose_keypoints_2d': [], 
