@@ -12,8 +12,8 @@
 
     Usage: 
         from Pose2Sim.Utilities import calib_qca_to_toml; calib_qca_to_toml.calib_qca_to_toml_func(r'<input_qca_file>')
-        OR python -m calib_qca_to_toml -i "<input_qca_file>"
-        OR python -m calib_qca_to_toml -i "<input_qca_file>" --binning_factor 2 -o "<output_toml_file>"
+        OR python -m calib_qca_to_toml -i input_qca_file
+        OR python -m calib_qca_to_toml -i input_qca_file --binning_factor 2 -o output_toml_file
 '''
 
 
@@ -31,7 +31,7 @@ __author__ = "David Pagnon"
 __copyright__ = "Copyright 2021, Pose2Sim"
 __credits__ = ["David Pagnon"]
 __license__ = "BSD 3-Clause License"
-__version__ = "0.1"
+__version__ = '0.4'
 __maintainer__ = "David Pagnon"
 __email__ = "contact@david-pagnon.com"
 __status__ = "Development"
@@ -42,6 +42,7 @@ def read_qca(qca_path, binning_factor):
     '''
     Read a Qualisys .qca.txt calibration file
     Returns 5 lists of size N (N=number of cameras):
+    - ret: residual reprojection error in _mm_: list of floats
     - C (camera name),
     - S (image size),
     - D (distorsion), 
@@ -51,12 +52,15 @@ def read_qca(qca_path, binning_factor):
     '''
 
     root = etree.parse(qca_path).getroot()
-    C, S, D, K, R, T = [], [], [], [], [], []
+    ret, C, S, D, K, R, T = [], [], [], [], [], [], []
+    vid_id = []
 
     # Camera name
-    for tag in root.findall('cameras/camera'):
-        if tag.attrib.get('model') in ('Miqus Video', 'none'):
-            C += [tag.attrib.get('serial')]
+    for i, tag in enumerate(root.findall('cameras/camera')):
+        ret += [float(tag.attrib.get('avg-residual'))/1000]
+        C += [tag.attrib.get('serial')]
+        if tag.attrib.get('model') in ('Miqus Video', 'Miqus Video UnderWater', 'none'):
+            vid_id += [i]
 
     # Image size
     for tag in root.findall('cameras/camera/fov_video'):
@@ -65,7 +69,7 @@ def read_qca(qca_path, binning_factor):
         S += [[w, h]]
     
     # Intrinsic parameters: distorsion and intrinsic matrix
-    for tag in root.findall('cameras/camera/intrinsic'):
+    for i, tag in enumerate(root.findall('cameras/camera/intrinsic')):
         k1 = float(tag.get('radialDistortion1'))/64/binning_factor
         k2 = float(tag.get('radialDistortion2'))/64/binning_factor
         p1 = float(tag.get('tangentalDistortion1'))/64/binning_factor
@@ -74,15 +78,17 @@ def read_qca(qca_path, binning_factor):
         
         fu = float(tag.get('focalLengthU'))/64/binning_factor
         fv = float(tag.get('focalLengthV'))/64/binning_factor
-        cu = float(tag.get('centerPointU'))/64/binning_factor
-        cv = float(tag.get('centerPointV'))/64/binning_factor
+        cu = float(tag.get('centerPointU'))/64/binning_factor \
+            - float(root.findall('cameras/camera/fov_video')[i].attrib.get('left'))
+        cv = float(tag.get('centerPointV'))/64/binning_factor \
+            - float(root.findall('cameras/camera/fov_video')[i].attrib.get('top'))
         K += [np.array([fu, 0., cu, 0., fv, cv, 0., 0., 1.]).reshape(3,3)]
 
     # Extrinsic parameters: rotation matrix and translation vector
     for tag in root.findall('cameras/camera/transform'):
-        tx = float(tag.get('x'))
-        ty = float(tag.get('y'))
-        tz = float(tag.get('z'))
+        tx = float(tag.get('x'))/1000
+        ty = float(tag.get('y'))/1000
+        tz = float(tag.get('z'))/1000
         r11 = float(tag.get('r11'))
         r12 = float(tag.get('r12'))
         r13 = float(tag.get('r13'))
@@ -98,18 +104,21 @@ def read_qca(qca_path, binning_factor):
         T += [np.array([tx, ty, tz])]
    
     # Cameras names by natural order
-    C_index = [C.index(c) for c in natural_sort(C)]
-    C = [C[c] for c in C_index]
-    S = [S[c] for c in C_index]
-    D = [D[c] for c in C_index]
-    K = [K[c] for c in C_index]
-    R = [R[c] for c in C_index]
-    T = [T[c] for c in C_index]
+    C_vid = [C[v] for v in vid_id]
+    C_vid_id = [C_vid.index(c) for c in natural_sort(C_vid)]
+    C_id = [vid_id[c] for c in C_vid_id]
+    C = [C[c] for c in C_id]
+    ret = [ret[c] for c in C_id]
+    S = [S[c] for c in C_id]
+    D = [D[c] for c in C_id]
+    K = [K[c] for c in C_id]
+    R = [R[c] for c in C_id]
+    T = [T[c] for c in C_id]
    
     return C, S, D, K, R, T
 
 
-def RT_qca2cv(r, t):
+def world_to_camera_persp(r, t):
     '''
     Converts rotation R and translation T 
     from Qualisys object centered perspective
@@ -120,7 +129,7 @@ def RT_qca2cv(r, t):
     '''
 
     r = r.T
-    t = - r.dot(t) 
+    t = - r @ t
 
     return r, t
 
@@ -135,10 +144,10 @@ def rotate_cam(r, t, ang_x=np.pi, ang_y=0, ang_z=0):
     r_ax_x = np.array([1,0,0, 0,np.cos(ang_x),-np.sin(ang_x), 0,np.sin(ang_x),np.cos(ang_x)]).reshape(3,3) 
     r_ax_y = np.array([np.cos(ang_y),0,np.sin(ang_y), 0,1,0, -np.sin(ang_y),0,np.cos(ang_y)]).reshape(3,3)
     r_ax_z = np.array([np.cos(ang_z),-np.sin(ang_z),0, np.sin(ang_z),np.cos(ang_z),0, 0,0,1]).reshape(3,3) 
-    r_ax = r_ax_z.dot(r_ax_y).dot(r_ax_x)
+    r_ax = r_ax_z @ r_ax_y @ r_ax_x
 
     r_ax_h = np.block([[r_ax,np.zeros(3).reshape(3,1)], [np.zeros(3), 1]])
-    r_ax_h__rt_h = r_ax_h.dot(rt_h)
+    r_ax_h__rt_h = r_ax_h @ rt_h
     
     r = r_ax_h__rt_h[:3,:3]
     t = r_ax_h__rt_h[:3,3]
@@ -186,8 +195,8 @@ def calib_qca_to_toml_func(*args):
 
     Usage: 
         import calib_qca_to_toml; calib_qca_to_toml.calib_qca_to_toml_func(r'<input_qca_file>')
-        OR calib_qca_to_toml -i "<input_qca_file>"
-        OR calib_qca_to_toml -i "<input_qca_file>" --binning_factor 2 -o "<output_toml_file>"
+        OR calib_qca_to_toml -i input_qca_file
+        OR calib_qca_to_toml -i input_qca_file --binning_factor 2 -o output_toml_file
     '''
     
     try:
@@ -207,7 +216,7 @@ def calib_qca_to_toml_func(*args):
 
     C, S, D, K, R, T = read_qca(qca_path, binning_factor)
     
-    RT = [RT_qca2cv(r,t) for r, t in zip(R, T)]
+    RT = [world_to_camera_persp(r,t) for r, t in zip(R, T)]
     R = [rt[0] for rt in RT]
     T = [rt[1] for rt in RT]
 
